@@ -10,15 +10,15 @@ from rich.logging import RichHandler
 
 from griffon.output import console
 
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 if "CORGI_API_URL" not in os.environ:
-    print("Must set CORGI_API_URL environment var.")
+    print("Must set CORGI_API_URL environment variable.")
     exit(1)
 CORGI_API_URL = os.environ["CORGI_API_URL"]
 
 if "OSIDB_API_URL" not in os.environ:
-    print("Must set OSIDB_API_URL environment var.")
+    print("Must set OSIDB_API_URL environment variable.")
     exit(1)
 OSIDB_API_URL = os.environ["OSIDB_API_URL"]
 
